@@ -161,16 +161,12 @@ if [ "$JAVA_CLASSPATH" ]; then
 else
     JAVA_CLASSPATH=
 fi
-if [ "$DESTDIR" ]; then
-    java_debug "Using DESTDIR = '$DESTDIR'"
-else
-    DESTDIR=""
-fi
+
 
 if [ "$JAVA_JARPATH" ]; then
     java_debug "Jar lookup is done in JAVA_JARPATH = '$JAVA_JARPATH'"
 else
-    JAVA_JARPATH=$DESTDIR/usr/share/java
+    JAVA_JARPATH=/usr/share/java
 fi
 
 
