@@ -49,7 +49,7 @@ __jvm_openjdk="$__jvm_openjdk7 $__jvm_openjdk6"
 # The java* runtimes:
 __jvm_java7="$__jvm_openjdk7"
 # -> corresponds to Provides: java6-runtime 
-__jvm_java6="$__jvm_openjdk6 $__jvm_sun6 $__jvm_java7"
+__jvm_java6="$__jvm_java7 $__jvm_openjdk6 $__jvm_sun6"
 # -> corresponds to Provides: java5-runtime 
 __jvm_java5="$__jvm_gcj5 $__jvm_java6"
 # -> corresponds to Provides: java2-runtime 
